@@ -3,7 +3,8 @@ from collections.abc import Sequence
 from dataclasses import dataclass
 
 import genanki
-import markdown
+
+from memium.utils.markdown_parser import to_html
 
 
 @dataclass(frozen=True)
@@ -11,18 +12,17 @@ class AnkiPrompt(ABC):
     base_deck: str
     tags: Sequence[str]
     uuid: int  # UUID is a unique identifier for the prompt, used for scheduling. If a new prompt is added with the same uuid, it will be treated as an update to the existing prompt. Otherwise, they will be interpreted as separate prompts.
+    edit_url: str | None
 
-    def field_to_html(self, field: str) -> str:
-        return markdown.markdown(field)
+    def _to_html(self, field: str) -> str:
+        return to_html(field)
 
     @property
     @abstractmethod
-    def genanki_model(self) -> genanki.Model:
-        ...
+    def genanki_model(self) -> genanki.Model: ...
 
     @abstractmethod
-    def to_genanki_note(self) -> genanki.Note:
-        ...
+    def to_genanki_note(self) -> genanki.Note: ...
 
     @property
     def deck(self) -> str:
